# The Fundamentals
## The Basic Properties of Numbers
**P1: Associative Law for Addition** ~ If *a*, *b*, and *c* are any numbers, then *a* + (*b* + *c*) = (*a* + *b*) + *c*.
**P2: Existence of an Additive Identity** ~ If *a* is any number, then *a* + 0 = 0 + *a* = *a*.
**P3: Existence of Additive Inverses** ~ For every number *a*, there is a number -*a* such that *a* + (-*a*) = (-*a*) + *a* = 0.
**P4: Commutative Law for Addition** ~ If *a* and *b* are any numbers, then *a* + *b* = *b* + *a*.
**P5: Associative Law for Multiplication** ~ If *a*, *b*, and *c* are any numbers, then *a* * (*b* * *c*) = (*a* * *b*) * *c*.
**P6: Existence of a Multiplicative Identity** ~ If *a* is any number, then *a* * 1 = 1 * *a* = *a*. In addition, 1 != 0 - All of the properties would hold if there were only one number (0).
**P7: Existence of Multiplicative Inverses** ~ For every number *a* != 0, there is a number *a*^(-1) such that *a* * *a*^(-1) = *a*^(-1) * *a* = 1.
**P8: Commutative Law for Multiplication** ~ If *a* and *b* are any numbers, then *a* * *b* = *b* * *a*.
**P9: Distributive Law** ~ If *a*, *b*, and *c* are any numbers, then *a* * (*b* + *c*) = *a* * *b* + *a* * *c*. It also follows that *a* * 0 = 0, (-*a*) * b = -(*a* * *b*), and (-*a*) * (-*b*) = *a* * *b*.
**Positive Number** ~ Any number *a* satifisying *a* > 0.
**Negative Number** ~ Any number *a* satisfying *a* < 0.

* The symbol for the **collection of all positive numbers** is denoted by *P*. Note that *a* > 0 if and only if *a* is in *P*.
* The following properties should be complemented with the following definitions:
    1. *a* > *b* if *a* - *b* is in P.
    2. *a* < *b* if *b* > *a*.
    3. *a* >= *b* if *a* > *b* or *a* = *b*.
    4. *a* <= *b* if *a* < *b* or *a* = *b*.

**P10: Trichotomy Law** ~ For every number *a*, one and only one of the following holds - (i). *a* = 0, (ii). a is in the collection *P*, (iii). -*a* is in the collection *P*.
**P11: Closure under addition** ~ If *a* and *b* are in *P*, then *a* + *b* is in *P*.
**P12: Closure under multiplication** ~ If *a* and *b* are in *P*, then *a* * *b* is in *P*.

* If *a* and *b* are any two numbers, then precisely one of the following holds:
    1. *a* - *b* = 0
    2. *a* - *b* is in *P*.
    3. -(*a* - *b*) = *b* - *a* is in *P*.
* From the previous definitions, then precisely one of the following holds:
    1. *a* = *b*.
    2. *a* > *b*.
    3. *b* > *a*.
* A few more facts result from the following manipulations:
    1. If *a* < *b*, then *a* + *c* < *b* + *c*.
    2. If *a* < 0, then -*a* > 0.
    3. If *a* < 0 and *b* < 0, then *ab* > 0. 
    4. From the last result, it follows that *a*^2 > 0 if *a* != 0.

**Absolute Value |*a*|** ~ For any number *a*, *a* if *a* >= 0 and -*a* if *a* <= 0.
* It is worth noting that |*a* + *b*| = |*a*| + |*b*| if *a* and *b* have the same sign and |*a* + *b*| < |*a*| + |*b*| if *a* and *b* are of opposite signs and also that |*a*| = sqrt(*a*^2). (The sqrt refers to the positive square root).

**Counting/Natural Numbers** ~ These numbers are denoted by its symbol **N**. They consist of 1, 2, 3, .... &&Although many properties do not apply to **N**, it is important because of its relation to "mathematical induction".&& &&The letter **N** comes from "Natural".&&
**The Principle of Mathematical Induction** ~ Suppose *P*(*x*) means that the property *P* holds for the number *x*. Then this principle states that *P*(*x*) is true for all natural numbers *x* provided that 1. *P*(1) is true. 2. Whenever *P*(*k*) is true, *P*(*k* + 1) is true.

**Null Set / Empty Collection** ~ This set/collection is denoted by a 0 with a bottom-left to top-right diagonal and is a collection of natural numbers that has no members at all. &&This is the only exception to the statement that if *A* is any collection of natural numbers, then *A* must have a smallest member.&&
**Well-ordering Principle** ~ This principle states that if *A* is a nonnull set of natural numbers, then *A* has a least member.
**The Principle of Complete Induction** ~ This principle states that if *A* is a set of natural numbers and (1) 1 is in *A*. (2) *k* + 1 is in *A* if 1, ... , *k* are in *A*. Then *A* is the set of all natural numbers.

**Integers** ~ These numbers are denoted by its symbol **Z**. They consist of ..., -2, -1, 0, 1, 2, .... &&The letter **Z** comes from the German word "Zahl" meaning number.&& 
**Rational Numbers** ~ These numbers are denoted by its symbol **Q**. They are formed by taking *m*/*n* of *Integers* with *n* != 0. &&The letter **Q** comes from "Quotients".&&
**Real Numbers** ~ These numbers are denoted by its symbol **R**. They consist of all of the *Rational Numbers* and also include the **Irrational Numbers**, which can be represented by infinite decimals (pi and sqrt(2)). It can be denoted as the open interval (-Inf, Inf).&&The letter **R** comes from "Real".&&
**Even Numbers** ~ These are *Natural Numbers* that are written in the form 2*k* for some integer *k*. &&When even numbers are squared, they remain even.&&
**Odd Numbers** ~ These are natural numbers that are written in the form 2*k* + 1 for some integer *k*. &&When odd numbers are squared, they remain odd.&&

## Functions

!**Ordered Pair** ~ This is denoted as (*a*, *b*) and is determined by *a* and *b*, and the order in which they are given: if (*a*, *b*) = (*c*, *d*), then *a* = *c* and *b* = *d*. More specifically, (*a*, *b*) = { {*a*}, {*a*, *b*} }
!**Function** ~ This is a rule which assigns, to each of certain real numbers, some other real number. They are commonly denoted by a letter, such as *f*, *g*, and *h*. A more *proper definition* is a collection of pairs of numbers with the following property: if (*a*, *b*) and (*a*, *c*) are both in the collection, then *b* = *c*; the collection must not contain two different pairs with the same first element.%%The rule which assigns to each number the square of that number can be represented as *f*(*x*) = *x*^2.%% %%If *f* is a function, then the number which *f* associates to a number *x* is denoted by *f*(*x*), read "*f* of *x*" and often called the value of *f* at *x*.%% %%We can consider the following set to be a function: *f* = {(1, 7), (3, 7), (5, 3), (4, 8), (8, 4).%%
!**Domain of a Function** ~ This is the set of numbers to which a function applies. A more *proper definition* is that if *f* is a function, this is the set of all *a* for which there is some *b* such that (*a*, *b*) is in *f*. If *a* is in this set, it follows from the definition of a function that there is a *unique* number *b* such that (*a*, *b*) is in *f*. This unique *b* is denoted by *f*(*a*). &&It is generally understood that when a function is defined, the qualifying phrase "for all *x*" is understood. Unless the domain is explicitly restricted further, it is understood to consist of all numbers for which the definition makes any sense at all.&&

**Polynomial Function** ~ This is a function *f* that can be defined as *f*(*x*) = *a*\_(*n*)*x*^(*n*) + *a*\_(*n* - 1)*x*^(*n* - 1) + ... + *a*\_2*x*^2 + *a*\_1*x* + *a*_0, for all *x*. \[\text{The}\textbf{ Polynomial Function } \text{can be defined as}:\] \[f(x) = a_{n}x^{n} + a_{n-1}x^{n-1} + ... + a_{2}x^2 + a_{1}x + a_{0} \text{ for all } x.\]

**Degree of a Function** ~ This is the highest power of *x* with a nonzero coefficient. &&The polynomial function *f* defined by *f*(*x*) = 5*x*&6 + 137*x*^4 - pi has a degree of 6.&&
**Rational Function** ~ This is a function of the form *p*/*q* where *p* and *q* are polynomial functions and *q* is not the function which is always 0.

**Function Sum** ~ If *f* and *g* are any two functions, this is defined as (*f* + *g*)(*x*) = *f*(*x*) + *g*(*x*). The domain of the resulting function is the intersection of the domain of *f* and the domain of *g*.
**Function Product** ~ If *f* and *g* are any two functions, this is defined as (*f* * *g*)(*x*) = *f*(*x*) * *g*(*x*). The domain of the resulting function is the intersection of the domain of *f* and the domain of *g*.
**Function Quotient** ~ If *f* and *g* are any two functions, this is defined as (*f* / *g*)(*x*) = *f*(*x*) / *g*(*x*). The domain of the resulting function is the intersection of the domain of *f* and the domain of *g* and where *g*(*x*) != 0.
**Constant Function** ~ This is a function *f* defined by *f*(*x*) = *c*, a function which has the same value for all numbers x. The domain of the ruslting function is the domain of *g*.
**Function Composition** ~ If *f* and *g* are any two functions, this is defined as (*f* o *g*)(*x*) = *f*(*g*(*x*)). The domain of the resulting function is {*x* : *x* is in the domain *g* and *g*(*x*) is in the domain *f*. &&The operation is read "*f* circle *g*" and {*x*: ...} means *x* such that "..."" is true.&&

**Even Function** ~ This is a function *f* if *f*(*x*) = *f*(-*x*).
**Odd Function** ~ This is a function *f* if *f*(*x*) = -*f*(*x*).

## Graphs

**Open Interval** ~ This is the set {*x*: *a* < *x* < *b*} denoted by (*a*, *b*). 
**Closed Interval** ~ This is the set {*x*: *a* <= *x* <= *b*} denoted by [*a*, *b*].
**Graph of a Function** ~ This is all of the points corresponding to pairs (*x*, *f*(*x*)) for a function *f*. 
**Distance** ~ If (*a*, *b*) and (*c*, *d*) are two points in the plane, this is equal to sqrt((a - c)^2 + (b - d)^2). \[\text{The}\textbf{ distance } \text{between two points } (a, b) \text{ and } (c, d) \text{ is equal to } \sqrt{\left(a - c\right)^2 + \left(b - d\right)^2}.\] 

**Linear Functions** ~ These are functions that can be denoted as *f*(*x*) = *cx* + *d* and is a straight line with slope *c*, passing through point (0, *d*).
**Parabola** ~ These are functions that can be denoted as *f*(*x*) = *x*^2.
**Power Functions** ~ These are functions that can be denoted as *f*(*x*) = *x*^*n* and are special cases of polynomial functions.

**Circle** ~ This is the set of all of the points (*x*, *y*) whose distance from (*a*, *b*) is equal to *r*. This means that it has a center (*a*, *b*) and radius *r* > 0 and can be denoted by sqrt((*x* - *a*)^2 + (*y* - *b*)^2) or (*x* - *a*)^2 + (*y* - *b*)^2 = *r*^2. &&The circle with center (0, 0) and radius 1 is called the **unit circle**.&&\[\text{The equation of a} \textbf{ circle } \text{with center } (a, b) \text{ and radius } r \text{ is }\] \[\sqrt{(x - a)^2 + (y - b)^2} = r \text{ or } (x - a)^2 + (y - b)^2 = r^2.\]

**Ellipse** ~ This is the set of all points, the sum of whose distances from two "focus" points is a constant. It can be denoted by x^2/a^2 + y^2/b^2 = 1 where b = sqrt(a^2 - c^2). \[\text{The equation of an}\textbf{ ellipse }\text{is }\frac{x^2}{a^2} + \frac{y^2}{b^2} = 1 \text{ where } b = \sqrt{a^2 - c^2}.\]

**Hyperbola** ~ This is the set of all points, the difference of whose distances from two "focus" points is a constant. It can be denoted by x^2/a^2 - y^2/b^2 = 1 where b = sqrt(c^2 - a^2). \[\text{The equation of a }\textbf{hyperbola}\text{ is } \frac{x^2}{a^2} - \frac{y^2}{b^2} = 1 \text{ where } b = \sqrt{c^2 - a^2}.\]

**Polar Coordinates:** ~ This is the collection of all points *P* with coordinates (*r*, theta) satisfying *r* = *f*(theta). Points with this coordinate system have cartesian coordinates given by *x* = *r cos*(theta), *y* = *r sin*(theta). Converting from cartesian to this coordinate system can be done through *r* = +- sqrt(x^2 + y^2) and *tan*(theta) = *y*/*x* if *x* != 0. \[\text{Polar Coordinates to Cartesian Coordinates : } x = r \cos{\theta},   y = r \sin{\theta}.\] \[\text{Cartesian Coordinates to Polar Coordinates : } r = \pm \sqrt{x^2 + y^2},   \tan{\theta} = \frac{y}{x} \text{ if } x \neq 0\].

# Calculus I
## Limits

**Tangent Line** ~ This is a line that just touches the graph of the function *f*(*x*) at the point *x* = *a* and is "parallel" to the graph at that point. It represents the **instantaneous rate of change** of *f*(*x*) at *x* = *a*. &&If the line isn't parallel, it is called a **secant line**, which represents the **average rate of change**.&&

!**Approaching a Limit** ~ The function *f* approaches (this) near *a*, if we can make *f*(*x*) as close as we like to (this) by requiring that *x* be sufficiently close to, but unequal to, *a*. The value at *x* = *a* does not matter, but only the values around *x* = *a*. A more formal definition is: Let *f*(*x*) be a function defined on an interval that contains *x* = *a*, except possibly at *x* = *a*. Then we say that, the limit as *x* approaches *a* of *f*(*x*) equals *L* if for every number epsilon > 0 there is some number delta > 0 such that |f(x) - L| < epsilon whenever 0 < |x - a| < delta. \[\text{The limit notation is: } \lim_{x \to a} f(x) = L. \] \[\text{Let } f(x) \text{ be a function defined on an interval that contains } x = a \text{, except possibly at } x = a \] \[\text{Then we say that, } \lim_{x \to a} f(x) = L \text{ if for every number} \epsilon > 0 \] \[\text{There is some number } \delta > 0 \text{ such that } \lvert f(x) - L \rvert < \epsilon \text{ whenever } 0 < \lvert x - a \rvert < \delta\]

* **Properties of Limits:**
    Property of Limits \(1. \lim_{x \to a} \left[cf(x)\right] = c\lim_{x \to a}f(x)\)
    Property of Limits \(2. \lim_{x \to a} \left[f(x) \pm g(x)\right] = \lim_{x \to a}f(x) \pm \lim_{x \to a}g(x)\)
    Property of Limits \(3. \lim_{x \to a} \left[f(x)g(x)\right] = \lim_{x \to a} f(x) \lim_{x \to a}g(x)\)
    Property of Limits \(4. \lim_{x \to a}\left[\frac{f(x)}{g(x)}\right] = \frac{\lim_{x \to a}f(x)}{\lim_{x \to a}g(x)}, \text{ provided } \lim_{x \to a}g(x) \neq 0\)
    Property of Limits \(5. \lim_{x \to a}\left[f(x)\right]^n = \left[\lim_{x \to a}f(x)\right]^n, \text{ where } n \text{ is any real number}\)
    Property of Limits \(6. \lim_{x \to a}\left[\sqrt[n]{\lim_{x \to a}f(x)}\right] = \sqrt[n]{\lim_{x \to a}f(x)}\)
    Property of Limits \(7. \lim_{x \to a}c = c, c \text{ is any real number}\)
    Property of Limits \(8. \lim_{x \to a}x = a\)
    Property of Limits \(9. \lim_{x \to a} x^n = a^n\)

** * Different Ways to Find Limits:**
    1. If the function is continuous, find *f*(*a*).
    2. Simplifying (Factoring, Distributing, Rationalizing)
    3. Squeeze Theorem

**Squeeze Theorem** ~ This theoreom states that if *f*(*x*) <= *h*(*x*) <= *g*(*x*) for all *x* on [*a*, *b*], and if lim_(*x* -> *c*) *f*(*x*) = lim_(*x* -> *c*) *g*(*x*) = *L* for some *a* <= *c* <= *b*, then lim_(*x* -> *c*) *h*(*x*) = *L*. \[\text{Suppose that for all } x \text{ on } \left[a, b\right] (\text{ except possibly at } x = c) \text{ we have, } f(x) \leq h(x) \leq g(x)\] \[\text{And also suppose that, } \lim_{x \to c} f(x) = \lim_{x \to c} g(x) = L \text{ for some } a \leq c \leq b \] \[\text{Then } lim_{x \to c} h(x) = L\]

**Vertical Asymptote** ~ A function *f*(*x*) has one of these at *x* = *a* if we have *any* of the following limits at *x* = *a*: 1. limit from the left approaches positive or negative infinity. 2. limit from the right approaches positive or negative infinity. 3. limit approaches positive or negative infinity.
**Horizontal Asymptote** ~ A function *f*(*x*) has one of these at *y* = *L* if either of the following limits are true: 1. limit approaching positive infinity of *f*(*x*) = *L*. 2. limit approaching negative infinity of *f*(*x*) = *L*.

* **Properties of Limits that Approach Infinity:**
    Given the functions *f*(*x*) and *g*(*x*), suppose we have \(\lim_{x \to c} f(x) = \infty, \lim_{x \to c} g(x) = L\)
    Properties of Limits that Approach Infinity \(1. \lim_{x \to c} \left[f(x) \pm g(x)\right] = \infty \)
    Properties of Limits that Approach Infinity \(2. \text{If } L > 0 \text{ then } \lim_{x \to c} \left[f(x)g(x)\right] = \infty\)
    Properties of Limits that Approach Infinity \(3. \text{If } L < 0 \text{ then } \lim_{x \to c} \left[f(x)g(x)\right] = -\infty\)
    Properties of Limits that Approach Infinity \(4. \lim_{x \to c} \frac{g(x)}{f(x)} = 0\)

**Continuity** ~ A function *f*(*x*) is said to have this property at *x* = *a* if the limit as *x* approaches *a* of *f*(*x*) equals *f*(*a*) (assuming that both *f*(*a*) and the limit as *x* approaches *a* of *f*(*x*) exist. It is said to have this property on the interval [*a*, *b*] if it has this property at each point in the interval. This would prove that the limit as *x* approaches *a* of *f*(*x*) from the left, right, and generally, all equal *f*(*a*). A more proper definition would be: Let *f*(*x*) be a function defined on an interval that contains *x* = *a*. Then we say that *f*(*x*) has this property at *x* = *a* if for every number (epsilon) > 0 there is some number (delta) > 0 such that |*f*(*x*) - *f*(*a*)| < (epsilon) whenever 0 < |*x* - *a*| < (delta). &&An easy way to think of Continuity is if we can draw the graph from start to finish without ever picking up our pencil.&&\[\lim_{x \to a} f(x) = f(a), \lim_{x \to a^-} f(x) = f(a), \lim_{x \to a^+} f(x) = f(a)\]

**Jump Discontinuity** ~ This exists where the graph has a break in it and the values of the function to either side of the break are finite, meaning that if this were at *x* = *a*, then *f*(*a*) exists but the limit as *x* approaches *a* doesn't.
**Removable Discontinuity** ~ This exists where the graph has a hole in the graph, meaning that if this were at *x* = *a*, then *f*(*a*) doesn't exist but the limit as *x* approaches *a* does.

* \(\text{If } f(x) \text{ is continuous at } x = b \text{ and } \lim_{x \to a} g(x) = b \text{ then } \lim_{x \to a} f(g(x)) = f(\lim_{x \to a} g(x)).\)

**Intermediate Value Theoreom** ~ Suppose that *f*(*x*) is continuous on [*a*, *b*] and let *M* be any number between *f*(*a*) and *f*(*b*). This theoreom states that there exists a number *c* such that 1. a < c < b. 2. f(c) = M. &&This theoreom basically states that somewhere between the two points on the interval, the function will have a value in between the values of the end points.&&

**Countably Infinite** ~ An infinite set of numbers is said to have this property if we can find a way to list them all out. An example of this are the natural numbers and rational numbers.
**Uncountably Infinite** ~ An infinite set of numbers is said to have this property if there is no possible way to list them all out. An example of this are the numbers in (0, 1).

    

## Derivatives
**Derivative With Respect to X** ~ This is denoted by *f*'(*x*) = the limit as *h* approaches 0 of (*f*(*x* + *h*) - *f*(*x*))/*h*. \[\text{The } \textbf{derivative of } f(x) \textbf{ with respect to x } \text{is the function } f'(x) \] \[\text{Defined as: } f'(x) = lim_{h \to 0} \frac{f(x + h) - f(x)}{h}\]

* The derivative can be interpreted in many ways:
    * Rate of change
    * Slope of the tangent line
    * Velocity

**Differentiable** ~ A function *f*(*x*) is said to have this property at *x* = *a* if *f*'(*a*) exists and *f*(*x*) is said to have this property on an interval if *f*'(*a*) exists for each point in that interval. &&If *f*(*x*) is differentiable at *x* = *a* then *f*(*x*) is continuous at *x* = *a*.&&

* Different Notations for the Derivative:
    * \(f' = f'(x) = y' = \frac{df}{dx} = \frac{dy}{dx} = \frac{d}{dx}(f(x)) = \frac{d}{dx}(y)\)
* Different Notations for Evaluating the Derivative at *x* = *a*:
    * \(f'(a) = y'\rvert_{x=a} = \frac{df}{dx}\rvert_{x=a} = \frac{dy}{dx}\rvert_{x=a}\)
* Properties of Derivatives:
    \(1. (f(x) \pm g(x))' = f'(x) \pm g'(x) \text{  OR  } \frac{d}{dx}(f(x) \pm g(x)) = \frac{df}{dx} \pm \frac{dg}{dx}\)
    \(2. (cf(x))' = cf'(x) \text{  OR  } \frac{d}{dx}(cf(x)) = c\frac{df}{dx}, c \text{ is any number}\)

The **Derivative of a constant** is zero. 
**The Power Rule** ~ This is a formula that states that if *x* is a variable and *n* is a number, then if *f*(*x*) = *x*^*n* then *f*'(*x*) = *nx*^(*n* - 1) or *d*/*dx*(*x*^*n*) = *nx*^(*n* - 1). &&It is useful to convert radicals to fractional exponents and then simplify exponents as much as possible when trying to derivate any equation.&& \[\text{If } f(x) = x^n \text{ then } f'(x) = nx^{n -1}\]

**The Product Rule** ~ This is a formula that states that if the two functions *f*(*x*) and *g*(*x*) are differentiable then the product is differentiable and (*fg*)' = *f*'*g* + *fg*'. \[(fg)' = f'g + fg'\] &&The product rule can be extended to more than two functions: (fgh)' = f'gh + fg'h + fgh'.&&
**The Quotient Rule** ~ This is a formula that states that if the two functions *f*(*x*) and *g*(*x*) are differentiable then the quotient is differentiable and (*f*/*g*)' = (*f*'*g* - *fg*')/g^2. \[\left(\frac{f}{g}\right)' = \frac{f'g - fg'}{g^2}\]

**Two Important Trigonometry Limits** ~ \(lim_{\theta \to 0} \frac{\sin\theta}{\theta} = 1 \text { and } \lim_{\theta \to 0}\frac{\cos\theta - 1}{\theta} = 0.\)
**Derivatives of the Six Trig Functions** ~ sin(*x*) -> cos(*x*), cos(*x*) -> -sin(*x*), tan(*x*) -> sec^2(*x*), cot(*x*) -> -csc^2(*x*), sec(*x*) -> sec(*x*)tan(*x*), csc(*x*) -> -csc(*x*)cot(*x*). \[\begin{array}{ll}\frac{d}{{dx}}\left( {\sin \left( x \right)} \right) = \cos \left( x \right) & \frac{d}{{dx}}\left( {\cos \left( x \right)} \right) =  - \sin \left( x \right)\\  \frac{d}{{dx}}\left( {\tan \left( x \right)} \right) = {\sec ^2}\left( x \right) & \frac{d}{{dx}}\left( {\cot \left( x \right)} \right) =  - {\csc ^2}\left( x \right)\\  \frac{d}{{dx}}\left( {\sec \left( x \right)} \right) = \sec \left( x \right)\tan \left( x \right) & \frac{d}{{dx}}\left( {\csc \left( x \right)} \right) =  - \csc \left( x \right)\cot \left( x \right)\end{array}\]

**Derivative of Inverses** ~ If *f*(*x*) and *g*(*x*) are inverses of each other, then *g*'(*x*) = 1/(*f*'(*g*(*x*))).\[\text{If } f(x) \text{ and } g(x) \text{ are inverses of each other, then } g'(x) = \frac{1}{f'(g(x))}.\]

**Derivative of Exponentials and Logarithms** ~ *a*^*x* -> *a*^*x* * ln(*a*). log_*a*(*x*) -> 1 / (*x* ln(*a*)). \[\begin{array}{ll} \frac{d}{{dx}}\left( {{{\bf{e}}^x}} \right) = {{\bf{e}}^x} & \frac{d}{{dx}}\left( {{a^x}} \right) = {a^x}\ln a\\ \frac{d}{{dx}}\left( {\ln x} \right) = \frac{1}{x} & \frac{d}{{dx}}\left( {{{\log }_a}x} \right) = \frac{1}{{x\ln a}}\end{array}\]

**Derivatives of the Six Inverse Trig Functions** ~ sin^-1(*x*) -> 1/(sqrt(1-*x*^2)), cos^-1(*x*) -> -1/(sqrt(1-*x*^2), tan^-1(*x*) -> 1/(1+*x*^2), cot^-1(*x*) -> -1/(1+*x*^2), sec^-1(*x*) -> 1/(|*x*|sqrt(*x*^2-1)), csc^-1(*x*) -> -1/(|*x*|sqrt(*x*^2-1)). \[\begin{array}{ll}\frac{d}{{dx}}\left( {{{\sin }^{ - 1}}x} \right) = \frac{1}{{\sqrt {1 - {x^2}} }} & \frac{d}{{dx}}\left( {{{\cos }^{ - 1}}x} \right) =  - \frac{1}{{\sqrt {1 - {x^2}} }}\\ \frac{d}{{dx}}\left( {{{\tan }^{ - 1}}x} \right) = \frac{1}{{1 + {x^2}}} & \frac{d}{{dx}}\left( {{{\cot }^{ - 1}}x} \right) =  - \frac{1}{{1 + {x^2}}}\\ \frac{d}{{dx}}\left( {{{\sec }^{ - 1}}x} \right) = \frac{1}{{\left| x \right|\sqrt {{x^2} - 1} }} & \frac{d}{{dx}}\left( {{{\csc }^{ - 1}}x} \right) =  - \frac{1}{{\left| x \right|\sqrt {{x^2} - 1} }}\end{array}\]

**Chain Rule** ~ Suppose we have two functions *f*(*x*) and *g*(*x*) and they are both differentiable. Then this rule states that 1. If we define *F*(*x*) = *f*(*g*(*x*)) then the derivative of *F*(*x*) is *F*'(*x*) = *f*'(*g*(*x*)) *g*'(*x*). 2. If we have *y* = *f*(*u*) and *u* = *g*(*x*) then the derivative of *y* is *dy*/*dx* = *dy*/*du* *du*/*dx*. &&We can think of the chain rule by identifying the "inside function" and the "outside function" and then differentiating the outside function while leaving the inside function alone and then multiplying by the derivative of the inside function.&& \[F'(x) = f'(g(x)) g'(x), \frac{dy}{dx} = \frac{dy}{du} \frac{du}{dx}\] 

**Implicit Differentiation** ~ This is when you replace *y* with *y*(*x*) and then derivate. Then you can isolate *dy*/*dx* on one side of the equation and set it equal in terms of *y* and *x*. Plugging in *y* from the original function, you can find the derivative of *y* with respect to *x*.

* \(\text{If } p(x) \text{ is a polynomial of degree } n \text{ then } p^{\left(k\right)} (x) = 0, \text{ for } k \geq n + 1\)

**Logarithmic Differentiation** ~ This is a type of differentiation where you take the natural log of both sides and then implicitly differentiate. It is useful for avoiding lengthy product/quotient rules and also lengthy exponentially chained functions. 

## Applications of Derivatives

**Critical Points** ~ We say that *x* = *c* is this of the function *f*(*x*) if *f*(*c*) exists and if either of the following are true: 1. *f*'(*c*) = 0. 2. *f*'(*c*) doesn't exist. To find these points, set *f*'(*x*) equal to 0 and find roots and points where *f*'(*x*) doesn't exist.

**Extrema** ~ These are the minimum and maximum points of a function. 
**Relative Maximum** ~ We say that *x* = *c* is this of the function *f*(*x*) if *f*(*x*) <= *f*(*c*) for every *x* in some open interval around *x* = *c*. This exists on a critical point if the values of *f*'(*x*) change from positive to negative (if reading left to right).
**Relative Minimum** ~ We say that *x* = *c* is this of the function *f*(*x*) if *f*(*x*) >= *f*(*c*) for every *x* in some open interval aronud *x* = *c*. This exists on a critical point if the values of *f*'(*x*) change from negative to positive (if reading from left to right). 
**Absolute Maximum** ~ We say that *x* = *c* is this of the function *f*(*x*) if *f*(*x*) <= *f*(*c*) for every *x* in the domain we are working on. This can be found by finding all of the critical points of a function in the domain we are working on and the end points and finding the point with the highest value.
**Absolute Minimum** ~ We say that *x* = *c* is this of the function *f*(*x*) if *f*(*x*) >= *f*(*c*) for every *x* in the domain we are working on. This can be found by finding all of the critical points of a function in the domain we are working on and the end points and finding the point with the lowest value.

**Extreme Value Theorem** ~ Suppose that *f*(*x*) is continuous on the interval [*a*, *b*]. Then this theorem states that there are two numbers *a* <= *c*, *d* <= *b* such that *f*(*c*) is an absolute maximum for the function and *f*(*d*) is an absolute minimum for the function.
**Fermat's Theorem** ~ If *f*(*x*) has a relative extrema at *x* = *c* and *f*'(*c*) exists, then this theorem states that *x* = *c* is a critical point of *f*(*x*) such that *f*'(*c*) = 0.

**How to Tell if a Function is Increasing/Decreasing/Constant** ~ If *f*'(*x*) > 0, then *f*(*x*) is \_\_\_. If *f*'(*x*) < 0, then *f*(*x*) is \_\_\_. If *f*'(*x*) = 0, then *f*(*x*) is \_\_\_.
**First Derivative Test** ~ This is a test by which you use the following facts to find a function's extrema: Suppose that *x* = *c* is a critical point of *f*(*x*). Then 1. If *f*'(*x*) > 0 to the left of *x* = *c* and *f*'(*x*) < 0 to the right of *x* = *c*, then *x* = *c* is a relative maximum. 2. If *f*'(*x*) < 0 to the left of *x* = *c* and *f*'(*x*) > 0 to the right of *x* = *c* then *x* = *c* is a relative minimum. 3. If *f*'(*x*) is the same sign on both sides of *x* = *c* then *x* = *c* is neither a relative maximum nor a relative minimum.

**Concavity** ~ Given the function *f*(*x*): 1. It is \_\_\_ up on an interval *I* if all of the tangents to the curve on *I* are below the graph of *f*(*x*). 2. It is \_\_\_ down on an interval *I* if all of the tangents to the curve on *I* are above the graph of *f*(*x*).
**How to Tell if a Function is Concave Up/Down** ~ If *f*''(*x*) > 0 for all *x* in some interval *I* then *f*(*x*) is \_\_\_ on *I*. If *f*''(*x*) < 0 for all *x* in some interval *I* then *f*(*x*) is \_\_\_ on *I*.
**Point of Inflection** ~ A point *x* = *c* is known as this if the function in continuous at the point and the concavity of the graph changes at that point.
**Second Derivative Test** ~ Suppose that *x* = *c* is a critical point of *f*'(*c*) such that *f*'(*c*) = 0 and that *f*''(*x*) is continuous in a region around *x* = *c*. Then 1. If *f*''(*c*) < 0 then *x* = *c* is a relative maximum. 2. If *f*''(*c*) > 0 then *x* = *c* is a relative minimum. 3. If *f*''(*c*) = 0 then *x* = *c* can be a relative maximum, relative minimum, or neither.
**Rolle's Theorem** ~ Suppose *f*(*x*) is a function that satisfies all of the following: 1. *f*(*x*) is continuous on the closed interval [*a*, *b*]. 2. *f*(*x*) is differentiable on the open interval (*a*, *b*). 3. *f*(*a*) = *f*(*b*). Then this theorem states that there is a number *c* such that *a* < *c* < *b* and *f*'(*c*) = 0. Or, in other words, *f*(*x*) has a critical point in (*a*, *b*). 
**Mean Value Theorem** ~ Suppose *f*(*x*) is a function that satisfies both of the following: 1. *f*(*x*) is continuous on the closed interval [*a*, *b*]. 2. *f*(*x*) is differentiable on the open interval (*a*, *b*). Then this theorem states that there is a number *c* such that *a* < *c* < *b* and *f*'(*c*) = (*f*(*b*) - *f*(*a*)) / (*b* - *a*). \[\text{There is a number } c \text{ such that } a < c < b \text{ and } f'(c) = \frac{f(b) - f(a)}{b - a}\]
**Indeterminate Forms** ~ These are end results of taking limits such that there are competing interests or rules and it's not clear which will win out. The following are of this form: 0/0, Inf/-Inf, (0)(+- Inf), 1^Inf, 0^0, Inf^0, Inf - Inf.
**L'Hospital's Rule** ~ Suppose that we have one of the following cases: lim_(*x* -> *a*) *f*(*x*)/*g*(*x* = 0/0 OR = +-Inf/+-Inf, where *a* can be any real number infinity or negative infinity. Then this rule states that lim_(*x*->*a*) *f*(*x*)/*g*(*x*) = lim_(*x*->*a*) *f*'(*x*)/*g*'(*x*). \[lim_{x \to a} \frac{f(x)}{g(x)} = lim_{x \to a} \frac{f'(x)}{g'(x)}\]
**Linear Approximation** ~ Given a function *f*(*x*), this method uses its tangent at *x* = *a* to get the line *L*(*x*) = *f*(*a*) + *f*'(*a*)(*x* - *a*) to determine an approximate value at another *x* value close to *a*.
**Differential** ~ Given a function *y* = *f*(*x*), these are what we call *dy* and *dx* and the relation between them as given by *dy* = *f*'(*x*)*dx*.
**Newton's Method** ~ If *x*\_*n* is an approximation for a solution of *f*(*x*) = 0 and if *f*'(*x*\_*n*) != 0 then this method's approximation is given by *x*\_(*n* + 1) = *x*\_*n* - *f*(*x*\_*n*) / *f*'(*x*\_*n*). \[\text{The next approximation is given by } x_{n + 1} = x_n - \frac{f(x_n)}{f'(x_n)}\] 

* Applications of Derivatives:
    * Rates of Change
        * Find derivatives and interpret them
    * Critical Points
    * Minimum and Maximums
    * Shape of a Graph
    * Mean-Value Theorem
    * Optimization
    * L'Hospital's Rule
    * Linear Approximations
    * Differentials
    * Newton's Method

* How to solve **Optimization** problems:
    1. Carefully read the problem and identify a) the constraint and b) the quantity to be optimized.
    2. Choose a method of optimization:
        * Find absolute extrema
        * First Derivative Test
        * Second Derivative Test
)
* How to solve **Related Rates** problems:
    1. Identify the information given and the problem
    2. Draw a picture
    3. Determine variables and constants
    4. Find a relationship between the variables
    5. If not all in one variable: Substitute variables
    6. Implicitly differentiate
    7. Plug in values

## Integrals

**Anti-Derivative, Indefinite Integral** ~ Given a function *f*(*x*), this is any function *F*(*x*) such that *F*'(*x*) = *f*(*x*). The most general version of this is called \_\_\_.

* Integral terminology and definitions:
    * \(\text{The } \textbf{Indefinite Integral} \text{ is denoted by } \int f(x) dx = F(x) + c, \text{ where } c \text{ is any constant.}\)
    * \(\text{In this definition, the } \int \text{ is called the } \textbf{integral symbol, } f(x) \text{ is called the } \textbf{integrand.}\)
    * \(x \text{ is called the } \textbf{integration variable} \text{ and the "} c \text{" is called the } \textbf{constant of integration.}\) 
    * \(\text{The process of finding the indefinite integral is called } \textbf{integration} \text{ or } \textbf{integrating } f(x).\) 
    * \(\text{To be specific about the integration variable, we are } \textbf{integrating } f(x) \textbf{ with respect to } x.\)

* Properties of the **Indefinite Integral**:
    \(1. \int kf(x) dx = k \int f(x) dx \text{ where } k \text{ is any number.}\)
    \(2. \int -f(x) dx = - \int f(x) dx.\)
    \(3. \int f(x) \pm g(x) dx = \int f(x) dx \pm \int g(x) dx.\)

**
**Integral Power Rule** ~ This is a general rule when integrating a power of *x*, except when *n* = 1. It is given by integral of *x*^*n* *dx* = (*x*^(*n*+1)) / (*n* + 1) + *c*, *n* != -1. \[\int x^n dx = \frac{x^{n + 1}}{n + 1}, n \neq -1\]

**Integrals of Six Trig Functions** ~ sin(*x*) -> -cos(*x*) + *c*, cos(*x*) -> sin(*     x*) + *c*, sec^2(*x*) -> tan(*x*) + *c*, sec(*x*)tan(*x*) -> sec(*x*), csc^2(*x*) -> -cot(*x*) + *c*, csc(*x*)cot(*x*) -> -csc(*x*) + *c*. \[\begin{array}{ll}\int{{\sin x\,dx}} =  - \cos x + c & \int{{\cos x\,dx}} = \sin x + c\\ \int{{{{\sec }^2}x\,dx}} = \tan x + c & \int{{\sec x\tan x\,dx}} = \sec x + c\\ \int{{{{\csc }^2}x\,dx}} =  - \cot x + c & \int{{\csc x\cot x\,dx}} =  - \csc x + c\end{array}\]

**Integrals of Six Inverse Trig Functions** ~ 1/sqrt(1 - *x*^2) -> arcsin(*x*) or -arccos(*x*), 1/(1 + *x*^2) -> arctan(*x*) or -arccot(*x*), 1/(*x*sqrt(*x*^2 - 1) -> arcsec(*x*)  or arccsc(*x*). \[\begin{array}{l} \frac{1}{\sqrt{1 - x^2}} = arcsin(x), -arccos(x) \\ \frac{1}{1 + x^2} = arctan(x), -arccot(x) \\ \frac{1}{\lvert x \rvert \sqrt{x^2 - 1}} = arcsec(x), -arccsc(x) \end{array}\]

**Integrals of Exponentials and Logarithms** ~ e^*x* -> e^*x*, *a*^*x* -> *a*^*x*/ln *a*, 1/*x* = *x*^-1 -> ln(|*x*|). \[\int e^x dx = e^x + c, \int a^x dx = \frac{a^x}{ln(a)} + c, \int \frac{1}{x} dx = \int x^{-1} = ln(\lvert x \rvert) + c\]

**Substitution Rule / U-Sub** ~ In general, this says that the integral of *f*(*g*(*x*)) *g*'(*x*) *dx* = the integral of *f*(*u*) *du*, where *u* = *g*(*x*). These problems are solved by setting *u* equal to an inner function, computing the differential *du* to substitute for the inner function's derivative (potentially after some modification), and then integrating with respect to *u*. If the bounds are kept tho same, then one must resubstitute *u* for whatever function it replaced before applying the bounds. Otherwise, if *u* is kept in the function, then the bounds must be transformed through the *u* = *g*(*x*) function before being applied. \[\int f(g(x)) g'(x) dx = \int f(u) du, \text{ where } u = g(x)\]

**Riemann Sum** ~ This is a summation denoted by A is approximately equal to the sum from *i*=1 to *n* of *f*(*x*\*_*i*) delta *x*. Assume *f*(*x*) >= 0 on [*a*, *b*] and divide the interval into *n* subintervals each of length delta *x* = (*b* - *a*) / *n*. Next, in each interval, choose a point *x*\*\_1, *x*\*\_2, ... *x*\*\_*i*, ..., *x*\*\_*n*. This approximates the area under a curve on a given interval. To get a better estimation, make *n* larger and larger; if we let it approach infinity then we get the exact area. \[A = \lim_{n \to \infty} \sum_{i=1}^n f(x^*_i) \Delta x\ \text{ where } \Delta x = \frac{b - a}{n}\]

**Definite Integral** ~ Given a function *f*(*x*) that is continuous on the interval [*a*, *b*], we divide the interval into *n* subintervals of equal width, Delta x, and from each interval choose a point, *x*\*\_i. Then this is the integral from *a* to *b* of *f*(*x*) *dx* = limit as *n* approaches infinity of the sum from *i* = 1 to *n* of *f*(*x*\*\_i) Delta x. &&The number *a* that is at the bottom of the integral sign is called the **lower limit/bound** of the integral and the number *b* that is at the top of the integral sign is called the **upper limit/bound** of the integral. Collectively, we call *a* and *b* the **interval of integration**.&& &&It is worth noting that when integrating **even functions** over the interval [*-a*, *a*] then the integral from -*a* to *a* will equal 2 times the integral from 0 to *a*. For odd functions over the same interval, the integral will equal 0.&&\[\int_a^b f(x) dx = \lim_{n \to \infty} \sum_{i=1}^n f(x^*_i) \Delta x\]

* Properties of the Definite Integral:
    \(1. \int_a^b f(x) dx = - \int_b^a f(x) dx\) 
    \(2. \int_a^a f(x) dx = 0\)  
    \(3. \int_a^b cf(x) = c \int_a^b f(x) dx \text{ where } c \text{ is any number.}\)  
    \(4. \int_a^b f(x) \pm g(x) dx = \int_a^b f(x) dx \pm \int_a^b g(x) dx\)  
    \(5. \int_a^b f(x) dx = \int_a^c f(x) dx + \int_c^b f(x) dx \text{ where } c \text{ is any number.}\)  
        * One of the main uses of this property is to integrate a function over adjacent intervals [a, c] and [c, b].
        * Note that *c* doesn't need to be between *a* and *b*.
    \(6. \int_a^b f(x) dx = \int_a^b f(t) dt\) 
    \(7. \int_a^b c dx = c(b - a) \text{ where } c \text{ is any number.}\) 
    \(8. \text{If } f(x) \geq 0 \text{ for } a \leq x \leq b \text{, then } \int_a^b f(x) dx \geq 0.\) 
    \(9. \text{If } f(x) \geq g(x) \text{ for } a \leq x \leq b \text{ then } \int_a^b f(x) dx \geq \int_a^b g(x) dx\) 
    \(10. \text{If } m \leq f(x) \leq M \text{ for } a \leq x \leq b \text{ then } m(b - a) \leq \int_a^b f(x) dx \leq M(b - a)\) 
    \(11. \lvert \int_a^b f(x) dx \rvert \leq \int_a^b \lvert f(x) \rvert dx\) 

**Net Change Theorem** ~ This theorem says that if *f*(*x*) is some quantity such that *f*'(*x*) is the rate of change of *f*(*x*), then the integral from *a* to *b* of *f*'(*x*) *dx* equals *f*(*b*) - *f*(*a*). &&This is basically the same thing as the Fundamental Theorem of Calculus, Part II&& \[\ \int_a^b f'(x) dx = f(b) - f(a)\]

**Fundamental Theorem of Calculus, Part I** ~ If *f*(*x*) is continuous on [*a*, *b*] then this theorem states that *g*(*x*) = integral from *a* to *x* of *f*(*t*)dt is continuous on [*a*, *b*] and differentiable on (*a*, *b*) and that *g*'(*x*) = *f*(*x*). \[\frac{d}{dx} \int_a^x f(t) dt = f(x)\]

**Fundamental Theorem of Calculus, Part II** ~ Suppose *f*(*x*) is a continuous function on [*a*, *b*] and also suppose that *F*(*x*) is any anti-derivative for *f*(*x*). Then this theorem states that the integral from *a* to *b* of *f*(*x*) *dx* = *F*(*x*)|^*b*\_*a* = *F*(*b*) - *F*(*a*). \[ \int_a^b f(x) dx = F(x) \rvert^b_a = F(b) - F(a)\]

* Applications of Integrals:
    * Average value of a function
    * Area between curves
    * Volumes of Solids of Revolution
    * Work done by an object

**How to Find Average Function Value** ~ The \_\_\_ of a function *f*(*x*) over the interval [*a*, *b*] is given by *f* = (1)/(*b* - *a*) times the integral from *a* to *b* *f*(*x*) *dx*. \[f_{avg} = \frac{1}{b - a} \int_a^b f(x) dx\]

**Mean Value Theorem for Integrals** ~ If *f*(*x*) is a continuous function on [*a*, *b*] then this theorem states that there is a number *c* in [*a*, *b*] such that the integral from *a* to *b* of *f*(*x*) dx = *f*(*c*) (*b* - *a*). and also that (1)/(b - a) times the integral from *a* to *b* *f*(*x*) *dx* = *f*(*c*). \[\int_a^b f(x) dx = f(c) (b - a)\] \[\frac{1}{b - a} \int_a^b f(x) dx = f(c)\]

**How to Find Area Between Two Curves** ~ There are two cases to this. 1: The \_\_\_ is equal to the integral from *a* to *b* of *f*(*x*) - *g*(*x*) *dx* where *f*(*x*) is the upper function and *g*(*x*) is the lower function. 2.: The \_\_\_ is equal to the integral from *a* to *b* of *f*(*y*) - *g*(*y*) where *f*(*y*) is the right function and *g*(*y*) is the left function. &&It is important to remember to convert your x-bounds into y-bounds if you converted a function of x to a function of y.&& \[A = \int_a^b \left( \frac{\text{upper}}{\text{function}} \right) - \left( \frac{\text{lower}}{\text{function}} \right) dx, a \leq x \leq b\] \[A = \int_c^d \left( \frac{\text{right}}{\text{function}} \right) - \left( \frac{\text{left}}{\text{function}} \right) dy, c \leq y \leq d\]

* A general formula for the volume of a solid is to determine the cross-sectional area *A*(*x*) or *A*(*y*) and use the following formulas: \(V = \int_a^b A(x) dx, V = \int_c^d A(y) dy\)

**Volume of a Solid of Revolution: Washer Method** ~ This can be found by rotating a function about an axis such that A = pi (radius)^2 if this is solid, or such that A = pi ( (outer radius)^2 - (inner radius)^2 ) if a portion of the solid is hollowed out. 

**Volume of a Solid of Revolution: Shells Method** ~ This can be found by rotating a function about an axis such that A = 2 pi (radius) (height). It requires functions to be in terms of y when rotating about the x-axis and function in terms of x when rotating about the y-axis.  